@@ -2,6 +2,7 @@
  *
  *  Copyright (c) 2006 Thomas Schreck <shrek@xfce.org>
  *  Copyright (c) 2010,2011 Florian Rivoal <frivoal@xfce.org>
+ *  Copyright (c) 2013 Harald Judt <h.judt@gmx.at>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef XFCE4_CPUFREQ_CONFIGURE_H
@@ -23,9 +24,16 @@
 
 typedef struct
 {
-	GtkWidget *display_icon, *display_freq, *display_governor;
-	GtkWidget *display_cpu, *display_frame, *monitor_timeout;
-	GtkWidget *combo_cpu, *spinner_timeout;
+	GtkWidget *display_icon;
+	GtkWidget *display_freq;
+	GtkWidget *display_governor;
+	GtkWidget *display_cpu;
+	GtkWidget *monitor_timeout;
+	GtkWidget *combo_cpu;
+	GtkWidget *spinner_timeout;
+	GtkWidget *keep_compact;
+	GtkWidget *one_line;
+	GtkWidget *fontname;
 } CpuFreqPluginConfigure;
 
 G_BEGIN_DECLS
