@@ -2,6 +2,7 @@
  *
  *  Copyright (c) 2006 Thomas Schreck <shrek@xfce.org>
  *  Copyright (c) 2010,2011 Florian Rivoal <frivoal@xfce.org>
+ *  Copyright (c) 2013 Harald Judt <h.judt@gmx.at>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef XFCE4_CPUFREQ_H
@@ -24,6 +25,12 @@
 #include <gtk/gtk.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
 
+#define PLUGIN_WEBSITE ("http://goodies.xfce.org/projects/panel-plugins/xfce4-cpufreq-plugin")
+
+#define CPU_MIN (cpuFreq->cpus->len + 0)
+#define CPU_AVG (cpuFreq->cpus->len + 1)
+#define CPU_MAX (cpuFreq->cpus->len + 2)
+
 typedef struct
 {
 	guint  cur_freq;
@@ -38,27 +45,45 @@ typedef struct
 
 typedef struct
 {
-	guint 	 timeout; 	/* time between refreash */
-	guint	 show_cpu;  	/* cpu number in panel */
-	gboolean show_frame;
+	gint     min_perf_pct;
+	gint     max_perf_pct;
+	gint     no_turbo;
+} IntelPState;
+
+typedef struct
+{
+	guint 	 timeout;       /* time between refresh */
+	guint	 show_cpu;      /* cpu number in panel */
 	gboolean show_icon;
 	gboolean show_label_governor;
 	gboolean show_label_freq;
 	gboolean show_warning;
+	gboolean keep_compact;
+	gboolean one_line;
+	gchar   *fontname;
 } CpuFreqPluginOptions;
 
 typedef struct
 {
 	XfcePanelPlugin *plugin;
+	XfcePanelPluginMode panel_mode;
+	gint panel_size;
+	guint panel_rows;
 
 	/* Array with all CPUs */
 	GPtrArray *cpus;
 
-	/* Widgets */
-	GtkWidget   *ebox, *frame, *box, *icon, *label;
-	GtkTooltips *tooltip;
+	/* Calculated values */
+	CpuInfo *cpu_min;
+	CpuInfo *cpu_avg;
+	CpuInfo *cpu_max;
 
-	gint icon_size;
+	/* Intel P-State parameters */
+	IntelPState *intel_pstate;
+
+	/* Widgets */
+	GtkWidget *button, *box, *icon, *label;
+	gboolean layout_changed;
 
 	CpuFreqPluginOptions  *options;
 	gint 		      timeoutHandle;
@@ -68,6 +93,12 @@ CpuFreqPlugin *cpuFreq;
 
 G_BEGIN_DECLS
 
+void
+cpuinfo_free (CpuInfo *cpu);
+
+void
+cpufreq_label_set_font (void);
+
 gboolean
 cpufreq_update_plugin (void);
 
